@@ -1,15 +1,12 @@
 #[cfg(feature = "variant")]
 #[test]
 fn white_insufficient_material_in_horde() {
-    use shakmaty::fen::Fen;
-    use shakmaty::variant::Horde;
-    use shakmaty::Color;
-    use shakmaty::FromSetup;
-    use shakmaty::{CastlingMode, Position};
+    use std::{
+        fs::File,
+        io::{prelude::*, BufReader},
+    };
 
-    use std::fs::File;
-    use std::io::prelude::*;
-    use std::io::BufReader;
+    use shakmaty::{fen::Fen, variant::Horde, CastlingMode, Color, FromSetup, Position};
 
     fn assert_white_insufficient_material_in_horde<P>(
         fen: &str,
@@ -44,7 +41,6 @@ expected_outcome={:?}\n\n",
         );
     }
 
-
     let file =
         File::open("tests/horde_insufficient_material.csv").expect("failed to open test suite");
     let reader = BufReader::new(file);
